==> brynq_sdk_factorial-1.0.2.tar.gz: brynq_sdk_factorial-1.0.2/brynq_sdk_factorial/compensations.py <==
import requests
import pandas as pd


class Compensations:
    def __init__(self, factorial):
        self.factorial = factorial
        self.base_endpoint = '/resources/contracts/'

    def get(self,
            ids: list = None,
            contract_version_id: list[int] = None) -> pd.DataFrame:

        # Use locals() to get all function parameters as a dictionary. Do not move this down since it will include all variables in function scope
        func_params = list(locals().items())
        params = {}
        for param, value in func_params:
            if param != 'self' and value is not None:
                params[param] = value

        has_next_page = True
        result_data = pd.DataFrame()
        while has_next_page:
            response = self.factorial.session.get(url=f'{self.factorial.base_url}{self.base_endpoint}compensations',
                                                  params=params)
            response.raise_for_status()
            response_data = response.json()
            result_data = pd.concat([result_data, pd.DataFrame(response_data['data'])])
            has_next_page = response_data['meta']['has_next_page']
            if has_next_page:
                params['after_id'] = response_data['meta']['end_cursor']

        taxonomies = self.get_types()
        if not result_data.empty:
            result_data = pd.merge(result_data, taxonomies, left_on='contracts_taxonomy_id', right_on='id', suffixes=('', '_taxonomy'))

        return result_data

    def get_types(self,
                  ids: list = None,
                  legal_entity_ids: list[int] = None,
                  legal_entity_id: int = None) -> pd.DataFrame:

        # Use locals() to get all function parameters as a dictionary. Do not move this down since it will include all variables in function scope
        func_params = list(locals().items())
        params = {}
        for param, value in func_params:
            if param != 'self' and value is not None:
                params[param] = value

        has_next_page = True
        result_data = pd.DataFrame()
        while has_next_page:
            response = self.factorial.session.get(url=f'{self.factorial.base_url}{self.base_endpoint}taxonomies',
                                                  params=params)
            response.raise_for_status()
            response_data = response.json()
            result_data = pd.concat([result_data, pd.DataFrame(response_data['data'])])
            has_next_page = response_data['meta']['has_next_page']
            if has_next_page:
                params['after_id'] = response_data['meta']['end_cursor']

        return result_data

    def update(self, compensation_id: str, data: dict) -> requests.Response:
        response = self.factorial.session.put(url=f'{self.factorial.base_url}{self.base_endpoint}/{compensation_id}',
                                              json=data)
        response.raise_for_status()
        return response

    def delete(self, compensation_id: str) -> requests.Response:
        response = self.factorial.session.delete(url=f'{self.factorial.base_url}{self.base_endpoint}/{compensation_id}')
        response.raise_for_status()
        return response

    def create(self, data: dict) -> requests.Response:
        raise NotImplementedError

==> brynq_sdk_factorial-2.0.0.tar.gz: brynq_sdk_factorial-2.0.0/brynq_sdk_factorial/compensations.py <==
import requests
import pandas as pd


class Compensations:
    def __init__(self, factorial):
        self.factorial = factorial
        self.base_endpoint = '/resources/contracts/'

    def get(self,
            ids: list = None,
            contract_version_id: list[int] = None) -> pd.DataFrame:

        # Use locals() to get all function parameters as a dictionary. Do not move this down since it will include all variables in function scope
        func_params = list(locals().items())
        params = {}
        for param, value in func_params:
            if param != 'self' and value is not None:
                params[param] = value

        has_next_page = True
        result_data = pd.DataFrame()
        while has_next_page:
            response = self.factorial.session.get(url=f'{self.factorial.base_url}{self.base_endpoint}compensations',
                                                  params=params,
                                                  timeout=self.factorial.timeout)
            response.raise_for_status()
            response_data = response.json()
            result_data = pd.concat([result_data, pd.DataFrame(response_data['data'])])
            has_next_page = response_data['meta']['has_next_page']
            if has_next_page:
                params['after_id'] = response_data['meta']['end_cursor']

        taxonomies = self.get_types()
        if not result_data.empty:
            result_data = pd.merge(result_data, taxonomies, left_on='contracts_taxonomy_id', right_on='id', suffixes=('', '_taxonomy'))

        return result_data

    def get_types(self,
                  ids: list = None,
                  legal_entity_ids: list[int] = None,
                  legal_entity_id: int = None) -> pd.DataFrame:

        # Use locals() to get all function parameters as a dictionary. Do not move this down since it will include all variables in function scope
        func_params = list(locals().items())
        params = {}
        for param, value in func_params:
            if param != 'self' and value is not None:
                params[param] = value

        has_next_page = True
        result_data = pd.DataFrame()
        while has_next_page:
            response = self.factorial.session.get(url=f'{self.factorial.base_url}{self.base_endpoint}taxonomies',
                                                  params=params,
                                                  timeout=self.factorial.timeout)
            response.raise_for_status()
            response_data = response.json()
            result_data = pd.concat([result_data, pd.DataFrame(response_data['data'])])
            has_next_page = response_data['meta']['has_next_page']
            if has_next_page:
                params['after_id'] = response_data['meta']['end_cursor']

        return result_data

    def update(self, compensation_id: str, data: dict) -> requests.Response:
        response = self.factorial.session.put(url=f'{self.factorial.base_url}{self.base_endpoint}/{compensation_id}',
                                              json=data,
                                              timeout=self.factorial.timeout)
        response.raise_for_status()
        return response

    def delete(self, compensation_id: str) -> requests.Response:
        response = self.factorial.session.delete(url=f'{self.factorial.base_url}{self.base_endpoint}/{compensation_id}', timeout=self.factorial.timeout)
        response.raise_for_status()
        return response

    def create(self, data: dict) -> requests.Response:
        raise NotImplementedError
